==> rekor-1.1.0.tar.gz: rekor-1.1.0/pkg/types/jar/v0.0.1/fuzz_test.go <==
//
// Copyright 2023 The Sigstore Authors.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package jar

import (
	"archive/zip"
	"bytes"
	"context"
	"sync"
	"testing"

	fuzz "github.com/AdaLogics/go-fuzz-headers"

	jarutils "github.com/sassoftware/relic/lib/signjar"

	fuzzUtils "github.com/sigstore/rekor/pkg/fuzz"
	"github.com/sigstore/rekor/pkg/types/jar"
)

var initter sync.Once

func FuzzJarCreateProposedEntry(f *testing.F) {
	f.Fuzz(func(t *testing.T, propsData []byte) {
		initter.Do(fuzzUtils.SetFuzzLogger)

		version := "0.0.1"

		ff := fuzz.NewConsumer(propsData)

		props, cleanup, err := fuzzUtils.CreateProps(ff)
		if err != nil {
			t.Skip()
		}
		defer cleanup()

		it := jar.New()
		entry, err := it.CreateProposedEntry(context.Background(), version, props)
		if err != nil {
			t.Skip()
		}
		c, err := it.UnmarshalEntry(entry)
		if err != nil {
			t.Skip()
		}
		_, _ = c.IndexKeys()
	})
}

type zipFile struct {
	fileName string
	fileBody []byte
}

func FuzzJarutilsVerify(f *testing.F) {
	f.Fuzz(func(t *testing.T, data []byte) {
		ff := fuzz.NewConsumer(data)
		noOfFiles, err := ff.GetInt()
		if err != nil {
			return
		}
		zipFiles := make([]*zipFile, 0)
		for i := 0; i < noOfFiles%20; i++ {
			fileName, err := ff.GetString()
			if err != nil {
				return
			}
			fileBody, err := ff.GetBytes()
			if err != nil {
				return
			}
			zf := &zipFile{
				fileName: fileName,
				fileBody: fileBody,
			}
			zipFiles = append(zipFiles, zf)
		}
		if len(zipFiles) == 0 {
			return
		}

		buf := new(bytes.Buffer)
		w := zip.NewWriter(buf)
		for _, file := range zipFiles {
			f, err := w.Create(file.fileName)
			if err != nil {
				w.Close()
				return
			}
			_, err = f.Write([]byte(file.fileBody))
			if err != nil {
				w.Close()
				return
			}
		}

		w.Close()
		zipData := buf.Bytes()
		zipReader, err := zip.NewReader(bytes.NewReader(zipData), int64(len(zipData)))
		if err != nil {
			return
		}
		_, _ = jarutils.Verify(zipReader, false)
	})
}

==> rekor-1.1.1.tar.gz: rekor-1.1.1/pkg/types/jar/v0.0.1/fuzz_test.go <==
//
// Copyright 2023 The Sigstore Authors.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package jar

import (
	"archive/zip"
	"bytes"
	"context"
	"sync"
	"testing"

	fuzz "github.com/AdamKorcz/go-fuzz-headers-1"

	jarutils "github.com/sassoftware/relic/lib/signjar"

	fuzzUtils "github.com/sigstore/rekor/pkg/fuzz"
	"github.com/sigstore/rekor/pkg/types/jar"
)

var initter sync.Once

func FuzzJarCreateProposedEntry(f *testing.F) {
	f.Fuzz(func(t *testing.T, propsData []byte) {
		initter.Do(fuzzUtils.SetFuzzLogger)

		version := "0.0.1"

		ff := fuzz.NewConsumer(propsData)

		props, cleanup, err := fuzzUtils.CreateProps(ff)
		if err != nil {
			t.Skip()
		}
		defer cleanup()

		it := jar.New()
		entry, err := it.CreateProposedEntry(context.Background(), version, props)
		if err != nil {
			t.Skip()
		}
		c, err := it.UnmarshalEntry(entry)
		if err != nil {
			t.Skip()
		}
		_, _ = c.IndexKeys()
	})
}

type zipFile struct {
	fileName string
	fileBody []byte
}

func FuzzJarutilsVerify(f *testing.F) {
	f.Fuzz(func(t *testing.T, data []byte) {
		ff := fuzz.NewConsumer(data)
		noOfFiles, err := ff.GetInt()
		if err != nil {
			return
		}
		zipFiles := make([]*zipFile, 0)
		for i := 0; i < noOfFiles%20; i++ {
			fileName, err := ff.GetString()
			if err != nil {
				return
			}
			fileBody, err := ff.GetBytes()
			if err != nil {
				return
			}
			zf := &zipFile{
				fileName: fileName,
				fileBody: fileBody,
			}
			zipFiles = append(zipFiles, zf)
		}
		if len(zipFiles) == 0 {
			return
		}

		buf := new(bytes.Buffer)
		w := zip.NewWriter(buf)
		for _, file := range zipFiles {
			f, err := w.Create(file.fileName)
			if err != nil {
				w.Close()
				return
			}
			_, err = f.Write([]byte(file.fileBody))
			if err != nil {
				w.Close()
				return
			}
		}

		w.Close()
		zipData := buf.Bytes()
		zipReader, err := zip.NewReader(bytes.NewReader(zipData), int64(len(zipData)))
		if err != nil {
			return
		}
		_, _ = jarutils.Verify(zipReader, false)
	})
}
